:py:mod:`byma.iteral.nonstationary`
===================================

.. py:module:: byma.iteral.nonstationary


Submodules
----------
.. toctree::
   :titlesonly:
   :maxdepth: 1

   Newton/index.rst
   NonStationary/index.rst


Package Contents
----------------

Classes
~~~~~~~

.. autoapisummary::

   byma.iteral.nonstationary.NonStationary




.. py:class:: NonStationary


   Defines default options for the NonStationary method


